SsrSharedContext

Struct SsrSharedContext 

pub struct SsrSharedContext { /* private fields */ }
The shared context that should be used on the server side.

Implementations

Source

impl SsrSharedContext

pub fn new() -> Self

Creates a new shared context for rendering HTML on the server.

pub fn new_islands() -> Self

Creates a new shared context for rendering HTML on the server in “islands” mode.

This defaults to a mode in which the app is not hydrated, but allows you to opt into hydration for certain portions using SharedContext::set_is_hydrating.

pub async fn consume_buffers(&self) -> Vec<(SerializedDataId, String)>

Consume the data buffers, awaiting all async resources, returning both sync and async buffers. Useful to implement custom hydration contexts.

WARNING: this will clear the internal buffers, it should only be called once. A second call would return an empty vec![].